@@ -1,9 +1,10 @@
 import os
+from rb.similarity.word_vector_model import WordVectorModel
 
 from gensim.models import KeyedVectors
 
 from rb.core.lang import Lang
-from rb.similarity.vector_model import VectorModel, VectorModelType
+from rb.similarity.vector_model import VectorModelType
 from rb.similarity.vector import Vector
 from rb.utils.downloader import download_model, check_version
 from rb.utils.rblogger import Logger
@@ -11,10 +12,10 @@ from rb.utils.rblogger import Logger
 logger = Logger.get_logger()
 
 
-class Word2Vec(VectorModel):
+class Word2Vec(WordVectorModel):
 
     def __init__(self, name: str, lang: Lang, dim: int = 300, check_updates=True):
-        VectorModel.__init__(self, VectorModelType.WORD2VEC, name, lang, dim, check_updates=check_updates)  
+        WordVectorModel.__init__(self, VectorModelType.WORD2VEC, name, lang, dim, check_updates=check_updates)  
         
 
     def load_vectors(self):
